package com.jiuqi.script.rhino;

import com.jiuqi.script.IScriptObject;
import java.util.Calendar;
import java.util.Date;
import org.mozilla.javascript.Context;
import org.mozilla.javascript.IdFunctionObject;
import org.mozilla.javascript.IdScriptableObject;
import org.mozilla.javascript.NativeJavaObject;
import org.mozilla.javascript.Scriptable;
import org.mozilla.javascript.ScriptableObject;

/* loaded from: com_jiuqi_script_rhino.jar:com/jiuqi/script/rhino/ScriptHelper.class */
public class ScriptHelper extends ScriptableObject {
    private Scriptable scope;

    /* JADX INFO: Access modifiers changed from: package-private */
    public ScriptHelper(Scriptable scope) {
        this.scope = scope;
        super.setParentScope(scope);
    }

    public Object toJava(Object obj) {
        return _toJava(obj, this.scope);
    }

    public Object toScript(Object obj) {
        return _toScript(obj, this.scope);
    }

    public void print(Object obj) {
        System.out.println(obj);
    }

    public String getClassName() {
        return "ScriptUtil";
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static Object _toJava(Object obj, Scriptable scope) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof RhinoScriptObject) {
            return ((RhinoScriptObject) obj).getScriptObject();
        }
        if (obj instanceof NativeJavaObject) {
            Object o = ((NativeJavaObject) obj).unwrap();
            if (o instanceof RhinoScriptObject) {
                return ((RhinoScriptObject) o).getScriptObject();
            }
            return o;
        }
        if (!(obj instanceof IdScriptableObject)) {
            return obj;
        }
        IdScriptableObject result = (IdScriptableObject) obj;
        if (result.getClassName().equals("Date")) {
            IdFunctionObject v = (IdFunctionObject) ScriptableObject.getProperty(result, "getTime");
            Object m = result.execIdCall(v, Context.getCurrentContext(), scope, result, (Object[]) null);
            long millis = ((Double) m).longValue();
            Calendar c = Calendar.getInstance();
            c.setTimeInMillis(millis);
            return c;
        }
        return result;
    }

    static Object _toScript(Object obj, Scriptable scope) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof IScriptObject) {
            return new RhinoScriptObject((IScriptObject) obj);
        }
        if (obj instanceof IdScriptableObject) {
            return obj;
        }
        if (obj instanceof NativeJavaObject) {
            Object result = ((NativeJavaObject) obj).unwrap();
            if (result instanceof IScriptObject) {
                return new RhinoScriptObject((IScriptObject) result);
            }
            if (result instanceof Calendar) {
                Calendar c = (Calendar) result;
                return Context.getCurrentContext().newObject(scope, "Date", new Object[]{new Long(c.getTimeInMillis())});
            }
            if (result instanceof Date) {
                Date d = (Date) result;
                return Context.getCurrentContext().newObject(scope, "Date", new Object[]{new Long(d.getTime())});
            }
        }
        return obj;
    }
}
